import React, { useState } from 'react';
import { Provider } from 'react-redux';
import store from 'foremanReact/redux';
import { MockedProvider } from '@apollo/react-testing';
import { MemoryRouter } from 'react-router-dom';
import { getForemanContext } from 'foremanReact/Root/Context/ForemanContext';
import { waitFor } from '@testing-library/react';

export const withRedux = Component => props => (
  <Provider store={store}>
    <Component {...props} />
  </Provider>
);

export const withRouter = Component => props => (
  <MemoryRouter>
    <Component {...props} />
  </MemoryRouter>
);

export const withMockedProvider = Component => props => {
  // eslint-disable-next-line react/prop-types
  const { mocks, ...rest } = props;

  const [context, setContext] = useState({
    metadata: {
      UISettings: {
        perPage: 20,
      },
    },
  });

  const contextData = { context, setContext };
  const ForemanContext = getForemanContext(contextData);
  return (
    <ForemanContext.Provider value={contextData}>
      <MockedProvider mocks={mocks}>
        <Component {...rest} />
      </MockedProvider>
    </ForemanContext.Provider>
  );
};

// use to resolve async mock requests for apollo MockedProvider
export const tick = () => new Promise(resolve => setTimeout(resolve, 0));

export const wait = async (tickCount = 1) => {
  for (let i = 1; i < tickCount; i++) {
    // eslint-disable-next-line no-await-in-loop
    await waitFor(tick);
  }
  return waitFor(tick);
};

export const historyMock = {
  location: {
    search: '',
  },
};

export const admin = {
  __typename: 'User',
  id: 'MDE6VXNlci00',
  login: 'admin',
  admin: true,
  permissions: {
    nodes: [],
  },
};

export const userFactory = (login, permissions = []) => ({
  __typename: 'User',
  id: 'MDE6VXNlci01',
  login,
  admin: false,
  permissions: {
    nodes: permissions,
  },
});

export const intruder = userFactory('intruder', [
  {
    __typename: 'Permission',
    id: 'MDE6UGVybWlzc2lvbi0x',
    name: 'view_architectures',
  },
]);

export const viewer = userFactory('viewer', [
  {
    __typename: 'Permission',
    id: 'MDE6UGVybWlzc2lvbi0yOTY=',
    name: 'view_oval_contents',
  },
  {
    __typename: 'Permission',
    id: 'MDE6UGVybWlzc2lvbi0yNzU=',
    name: 'view_oval_policies',
  },
]);

export const mockFactory = (resultName, query) => (
  variables,
  modelResults,
  { errors = [], currentUser = null } = {}
) => {
  const mock = {
    request: {
      query,
      variables,
    },
    result: {
      data: {
        [resultName]: modelResults,
      },
    },
  };

  if (errors.length !== 0) {
    mock.result.errors = errors;
  }

  if (currentUser) {
    mock.result.data.currentUser = currentUser;
  }
  return [mock];
};
